using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace RepPP.Toolkit {
    //********************************************************************************
    //
	/// <summary>
	/// Implement the property page to pickup a Rep++ Field
	/// </summary>
    //
    //********************************************************************************
	public class FormAtmControlPropPage : System.Windows.Forms.Form	{
		/// <summary>Required designer variable.</summary>
		private System.ComponentModel.Container     components = null;
		/// <summary>Atom control being edited</summary>
		private AtmControlUtil.IAtmControl          m_atmControl;
		/// <summary>true if filling the combobox</summary>
		private bool                                m_bFilling;
        private System.Windows.Forms.Button         butOk;
        private System.Windows.Forms.Button         butCancel;
        private System.Windows.Forms.Button         butApply;
        private System.Windows.Forms.ComboBox       comboBoxAtomType;
        private System.Windows.Forms.Label          labelAtomType;
        private System.Windows.Forms.ComboBox       comboBoxAtomName;
        private System.Windows.Forms.Label          labelAtomName;

        //********************************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
		/// <param name="atmControl">   Field control being edited</param>
        //
        //********************************************************************************
		public FormAtmControlPropPage(AtmControlUtil.IAtmControl atmControl) {
			InitializeComponent();
		    m_atmControl     = atmControl;
		    FillTypeCombo();
		    SetApplyButtonState();
		}

        //********************************************************************************
        //
        /// <summary>
        /// ctor:                       Class constructor
        /// </summary>
        //
        //********************************************************************************
		public FormAtmControlPropPage()	: this(null) {
		}

        //********************************************************************************
        //
        /// <summary>
        /// Dispose:                    Dispose the object
        /// </summary>
        /// <param name="bDisposing">   true if disposing, false if GC</param>
        //
        //********************************************************************************
		protected override void Dispose(bool bDisposing) {
			if (bDisposing)	{
				if (components != null)	{
					components.Dispose();
				}
			}
			base.Dispose(bDisposing);
		}

        //********************************************************************************
        //
        /// <summary>
        /// FillTypeCombo:              Fills the type combo box with the list of groups
        /// </summary>
        //
        //********************************************************************************
        private void FillTypeCombo() {
            AtmFullName atmFullName;
            
            m_bFilling = true;
            comboBoxAtomType.Items.Clear();
            if (m_atmControl != null) {
                atmFullName  = m_atmControl.AtomFullName;
                comboBoxAtomType.Items.Add(AtomType.sdAtomMsg.ToString());
                comboBoxAtomType.Items.Add(AtomType.sdAtomErr.ToString());
                comboBoxAtomType.SelectedIndex = (atmFullName.AtomType == AtomType.sdAtomErr) ? 1 : 0;
            }
            m_bFilling = false;
            FillAtomNameCombo();
        }

        //********************************************************************************
        //
        /// <summary>
        /// FillAtomNameCombo:          Fills the atom name combo box
        /// </summary>
        //
        //********************************************************************************
        private void FillAtomNameCombo() {
            RepPP.Application   app;
            AtmFullName         atmFullName;
            int                 iIndex;
            AtomType            eType;
            string              strAtmList;
            
            m_bFilling  = true;
            app         = (m_atmControl == null) ? null : m_atmControl.Application;
            comboBoxAtomName.Items.Clear();
            if (app != null) {
                atmFullName = m_atmControl.AtomFullName;
                if (comboBoxAtomType.SelectedIndex != -1) {
                    eType       = (AtomType)Enum.Parse(typeof(AtomType), comboBoxAtomType.SelectedItem as string);
                    strAtmList  = app.GetAtomList(eType);
                    comboBoxAtomName.Items.AddRange(strAtmList.Split(','));
                    if (atmFullName.AtomName != String.Empty) {
                        iIndex                         = comboBoxAtomName.Items.IndexOf(atmFullName.AtomName);
                        comboBoxAtomName.SelectedIndex = iIndex;
                    }
                }
            }
            m_bFilling = false;
            if (comboBoxAtomName.SelectedIndex == -1 && comboBoxAtomName.Items.Count != 0) {
                comboBoxAtomName.SelectedIndex = 0;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// SetApplyButtonState:    Enable or disable the apply button depending on the context
        /// </summary>
        //
        //********************************************************************************
        private void SetApplyButtonState() {
            bool        bState = false;
            int         iIndex1;
            int         iIndex2;
            AtmFullName atmFullName;
            
            if (m_atmControl != null) {
                atmFullName = m_atmControl.AtomFullName;
                iIndex1     = comboBoxAtomType.SelectedIndex;
                iIndex2     = comboBoxAtomName.SelectedIndex;
                if (iIndex1 != -1 && iIndex2 != -1) {
                    if (comboBoxAtomType.Items[iIndex1].ToString() != atmFullName.AtomType.ToString() ||
                        comboBoxAtomName.Items[iIndex2].ToString() != atmFullName.AtomName) {
                        bState = true;
                    }
                }
                butApply.Enabled = bState;
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// Apply:          Apply the change
        /// </summary>
        //
        //********************************************************************************
        private void Apply() {
            int         iIndex1;
            int         iIndex2;
            AtmFullName atmFullName;
            
            if (m_atmControl != null) {
                iIndex1 = comboBoxAtomType.SelectedIndex;
                iIndex2 = comboBoxAtomName.SelectedIndex;
                if (iIndex1 != -1 && iIndex2 != -1) {
                    atmFullName             = new AtmFullName((AtomType)Enum.Parse(typeof(AtomType), comboBoxAtomType.Items[iIndex1] as string),
                                                              comboBoxAtomName.Items[iIndex2] as string);
                    if (atmFullName.AtomType != m_atmControl.AtomFullName.AtomType ||
                        atmFullName.AtomName != m_atmControl.AtomFullName.AtomName) {
                        m_atmControl.AtomFullName  = atmFullName;
                        m_atmControl.TriggerComponentChange();
                    }
                }
            }
            butApply.Enabled = false;
        }

        //********************************************************************************
        //
        /// <summary>
        /// butOk_Click:            Called when the OK button is pressed
        /// </summary>
        /// <param name="sender">   Sender object</param>
        /// <param name="e">        Event parameters</param>
        //
        //********************************************************************************
        private void butOk_Click(object sender, System.EventArgs e) {
            Apply();
        }

        //********************************************************************************
        //
        /// <summary>
        /// butApply_Click:         Called when the Apply button is pressed
        /// </summary>
        /// <param name="sender">   Sender object</param>
        /// <param name="e">        Event parameters</param>
        //
        //********************************************************************************
        private void butApply_Click(object sender, System.EventArgs e) {
            Apply();
        }

        //********************************************************************************
        //
        /// <summary>
        /// comboBoxAtomType_SelectedIndexChanged:  Called when the combobox selection is changed
        /// </summary>
        /// <param name="sender">                   Sender object</param>
        /// <param name="e">                        Event parameters</param>
        //
        //********************************************************************************
        private void comboBoxAtomType_SelectedIndexChanged(object sender, System.EventArgs e) {
            if (!m_bFilling) {
                FillAtomNameCombo();
                SetApplyButtonState();
            }
        }

        //********************************************************************************
        //
        /// <summary>
        /// comboBoxAtomName_SelectedIndexChanged:  Called when the combobox selection is changed
        /// </summary>
        /// <param name="sender">                   Sender object</param>
        /// <param name="e">                        Event parameters</param>
        //
        //********************************************************************************
        private void comboBoxAtomName_SelectedIndexChanged(object sender, System.EventArgs e) {
            if (!m_bFilling) {
                SetApplyButtonState();
            }
        }

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.comboBoxAtomType = new System.Windows.Forms.ComboBox();
            this.comboBoxAtomName = new System.Windows.Forms.ComboBox();
            this.butOk = new System.Windows.Forms.Button();
            this.butCancel = new System.Windows.Forms.Button();
            this.butApply = new System.Windows.Forms.Button();
            this.labelAtomType = new System.Windows.Forms.Label();
            this.labelAtomName = new System.Windows.Forms.Label();
            this.SuspendLayout();
            // 
            // comboBoxAtomType
            // 
            this.comboBoxAtomType.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboBoxAtomType.Location = new System.Drawing.Point(152, 32);
            this.comboBoxAtomType.Name = "comboBoxAtomType";
            this.comboBoxAtomType.Size = new System.Drawing.Size(176, 21);
            this.comboBoxAtomType.TabIndex = 0;
            this.comboBoxAtomType.SelectedIndexChanged += new System.EventHandler(this.comboBoxAtomType_SelectedIndexChanged);
            // 
            // comboBoxAtomName
            // 
            this.comboBoxAtomName.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.comboBoxAtomName.Location = new System.Drawing.Point(152, 72);
            this.comboBoxAtomName.Name = "comboBoxAtomName";
            this.comboBoxAtomName.Size = new System.Drawing.Size(176, 21);
            this.comboBoxAtomName.TabIndex = 1;
            this.comboBoxAtomName.SelectedIndexChanged += new System.EventHandler(this.comboBoxAtomName_SelectedIndexChanged);
            // 
            // butOk
            // 
            this.butOk.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.butOk.Location = new System.Drawing.Point(144, 144);
            this.butOk.Name = "butOk";
            this.butOk.TabIndex = 2;
            this.butOk.Text = "OK";
            this.butOk.Click += new System.EventHandler(this.butOk_Click);
            // 
            // butCancel
            // 
            this.butCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.butCancel.Location = new System.Drawing.Point(232, 144);
            this.butCancel.Name = "butCancel";
            this.butCancel.TabIndex = 3;
            this.butCancel.Text = "Cancel";
            // 
            // butApply
            // 
            this.butApply.Location = new System.Drawing.Point(320, 144);
            this.butApply.Name = "butApply";
            this.butApply.TabIndex = 4;
            this.butApply.Text = "Apply";
            this.butApply.Click += new System.EventHandler(this.butApply_Click);
            // 
            // labelAtomType
            // 
            this.labelAtomType.Location = new System.Drawing.Point(40, 32);
            this.labelAtomType.Name = "labelAtomType";
            this.labelAtomType.Size = new System.Drawing.Size(88, 23);
            this.labelAtomType.TabIndex = 5;
            this.labelAtomType.Text = "Type";
            // 
            // labelAtomName
            // 
            this.labelAtomName.Location = new System.Drawing.Point(40, 72);
            this.labelAtomName.Name = "labelAtomName";
            this.labelAtomName.Size = new System.Drawing.Size(96, 23);
            this.labelAtomName.TabIndex = 6;
            this.labelAtomName.Text = "Atom";
            // 
            // FormAtmControlPage
            // 
            this.AcceptButton = this.butOk;
#if (VC70 || VC71)
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
#else
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
#endif
            this.CancelButton = this.butCancel;
            this.ClientSize = new System.Drawing.Size(408, 182);
            this.Controls.Add(this.labelAtomName);
            this.Controls.Add(this.labelAtomType);
            this.Controls.Add(this.butApply);
            this.Controls.Add(this.butCancel);
            this.Controls.Add(this.butOk);
            this.Controls.Add(this.comboBoxAtomName);
            this.Controls.Add(this.comboBoxAtomType);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
            this.Name = "FormAtmControlPropPage";
            this.Text = "Rep++ Atom Property Page";
            this.ResumeLayout(false);

        }
		#endregion

	} // Class
} // Namespace
