using System;
using System.Web;
using System.Web.UI;
using System.ComponentModel;

namespace RepPP.Toolkit.Web {
	/// <summary>
	/// Emulate a page with the PreInit event like the one found in ASP.Net 2.0
	/// </summary>
#if VC70 || VC71
	public class PagePreInit : Page {
	    /// <summary>Simulate the PreInit events found in ASP.Net 2.0</summary>
		public event System.EventHandler    PreInit;
		/// <summary>true if the PreInit has already been called</summary>
		private bool                        m_bPreInitCalled;

        //*********************************************************
        //
        /// <summary>
        /// ctor:                           Constructor
        /// </summary>
        //
        //*********************************************************
		public PagePreInit() {
		    m_bPreInitCalled = false;
		}

        //********************************************************************************
        //
	    /// <summary>
	    /// OnPreInit:                      Trigger the PreInit event
	    /// </summary>
        /// <param name="e">                Event arguments</param>
	    //
        //********************************************************************************
        protected virtual void OnPreInit(System.EventArgs e) {
            if (PreInit != null) {
                PreInit(this, e);
            }
        }

        //********************************************************************************
        //
	    /// <summary>
	    /// DeterminePostBackMode:          Intercept so we can initialize the Rep++ object before a child does it
	    ///                                 The child objects are initialized before OnInit is called. The ctor cannot
	    ///                                 be used to initialized Rep++ because the thread used to create the class is
	    ///                                 not always the same. This property is called just before the OnInit, so...
	    /// </summary>
	    //
        //********************************************************************************
        protected override System.Collections.Specialized.NameValueCollection DeterminePostBackMode() {
            System.Collections.Specialized.NameValueCollection  colRetVal;

            colRetVal = base.DeterminePostBackMode();
            if (!m_bPreInitCalled) {
                m_bPreInitCalled = true;
                OnPreInit(EventArgs.Empty);
            }
            return(colRetVal);
        }

        //********************************************************************************
        //
	    /// <summary>
	    /// PreviousPage:                   Returns the previous page in case of a transfer
	    /// </summary>
	    //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public virtual Page PreviousPage {
            get {
                Page    pageRetVal = null;
                
                if (Context != null) {
                    pageRetVal = (IsPostBack) ? null : Context.Handler as Page;
                    if (pageRetVal == this) {
                        pageRetVal = null;
                    }
                }
                return(pageRetVal);
            }
        }

        //********************************************************************************
        //
	    /// <summary>
	    /// IsCallback:                   Gets a value indicating whether the page request 
        ///                               is the result of a call
	    /// </summary>
	    //
        //********************************************************************************
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public bool IsCallback {
            get {
                return(false);
            }
        }
	}
#else
    public class PagePreInit : Page {

        //********************************************************************************
        /// <summary>
        /// FindControl             Searches the page naming container for a server control
        ///                         with the specified identifier.
        /// </summary>
        /// <param name="id">       id of the server control</param>
        /// <returns>The control if found, otherwise null</returns>
        //********************************************************************************
        public override Control FindControl(string id) {
            Control ctlRetVal;
            if (String.Compare(this.ID, id, true) == 0) {
                ctlRetVal = this;
            } else {
                if (Master == null) {
                    ctlRetVal = base.FindControl(id);
                } else {
                    ctlRetVal = Master.FindControl(id);
                    if (ctlRetVal == null) {
                        ctlRetVal = WebUtil.FindControlUsingID(Master.Controls, id);
                    }
                }
            }
            return(ctlRetVal);
        }
    }
#endif
}
